#include <stdio.h>
#include <string.h>
#include <ctype.h>
#define MAX_REC_LEN 100
#define MAX_ERR_LEN 100

/*
 * mkrequest:
 *
 * Written 1/8/96 JRC.  Based on SK's shell script and comments.
 * Assumes both input files are sorted.
 */

/*
 * function prototypes
 */
FILE *myfopen (char *);
void usage();
int mycompare (unsigned char *, unsigned char *);
unsigned char *myfgets (unsigned char *, int, FILE *);
void myprint (unsigned char *);


main (int argc, char *argv[]) {
	FILE *cf, *mf;
	unsigned char cr[MAX_REC_LEN], mr[MAX_REC_LEN];
	unsigned char *cr_stats, *mr_stats;
	int c;

	if (argc != 3)
		usage(argv[0]);

	cf = myfopen (argv[1]);
	mf = myfopen (argv[2]);

	/*
	 * for every file listed in masterstatfile, we check if it exists in
	 * mystatfile, and if so, whether its stats are the same
	 * if any of the stats are different, we write the filename to
	 * stdout, so that a new file will be requested from the master
	 * if it does not exist in mystatfile, we also request it
	 */

	myfgets (cr, MAX_REC_LEN, cf);
	fgets (mr, MAX_REC_LEN, mf);

	while (!feof (mf)) {
		while ((c = mycompare (cr, mr)) < 0) {  
			/* mystat-filename < masterstat-filename */
			myfgets (cr, MAX_REC_LEN, cf);
		}

		if (c) {
			/* mystat-filename > masterstat-filename */
			myprint (mr);
		}
		
		else {
			/* mystat-filename == masterstat-filename */
			cr_stats = strpbrk (cr, " \t") + 1;
			mr_stats = strpbrk (mr, " \t") + 1;
			if (strcmp (cr_stats, mr_stats))
				myprint (mr);
		}

		/* now get next record from masterstat file */
		fgets (mr, MAX_REC_LEN, mf);
	}
}


/* 
 * displays usage parameters and terminates
 */
void usage(char *prog) {
	printf ("Usage: %s mystatfile masterstatfile\n", prog);
	exit(1);
}

/*
 * opens a file for reading and returns the file descriptor
 * if an error occurs, prints the error and terminates
 */
FILE *myfopen(char *fname) {
	FILE *fp;
	char errmsg[MAX_ERR_LEN];

	fp = fopen (fname, "r");
	if (!fp) {
		sprintf (errmsg, "can't open file %s", fname);
		perror (errmsg);
		exit(1);
	}
	return (fp);
}

/*
 * lexically compares two alphanumeric strings, 
 * terminated by a whitespace character
 */
int mycompare (unsigned char *s1, unsigned char *s2) {
	while (!isspace (*s1) || !isspace (*s2)) {
		if (*s1 < *s2)
			return -1;
		else if (*s1 > *s2)
			return 1;
		s1++; s2++;
	}
	return 0;
}

/*
 * augmented fgets that fills the buffer with 0xff on EOF
 */
unsigned char *myfgets (unsigned char *s, int n, FILE *fp) {
	if (!fgets (s, n, fp)) {
		/* flag end of mystat file */
		memset (s, 0xff, MAX_REC_LEN-1);
	}

	return (s);
}

/*
 * print a string up until the first whitespace character
 */
void myprint (unsigned char *s) {
	while (*s != ' ' && *s != '\t')
		putchar (*s++);
	putchar ('\n');
}
