.TH AFDPSEND 1 "" "AFDP 0.98"
.SH NAME
afdpsend - send files to an AFDP group
.SH SYNOPSIS
.B afdpsend
[
.B \-DVdhr
]
[
.B \-a
.I aclfile
]
[
.B \-g
.I group_number
]
[
.B \-p
.I port
]
[
.B -s
.I secretary_host
]
[
.B \-c
.I command
]
[
.B \-o
.I confirm
]
[
.B \-o
.I warn
]
[
.B \-C
.I cache_size
]
[
.B \-MNRU
]
[
.B \-S
.I stepsize
]
[
.B \-b
.I broadcast_size
]
[
.B \-i
.I forced_interval
]
[
.B \-u
.I unicast_size
]
[
.B \-w
.I window_size
]
file ...
.SH DESCRIPTION
.PP
.I afdpsend
first tries to locate an AFDP secretary for the requested group (default
group id = 1). If a secretary_host is given on the command line, that
host is queried to find the secretary. If not, broadcast is used to 
locate a secretary on the local network.
If a secretary can't be located, afdpsend exits with status 1.
.PP
Once the secretary is found, afdpsend asks for permission to send
the files, and if permission is granted the secretary gives the
publisher required information about the group, such as publishing
method (broadcast, multicast or unicast), list of members,
multicast address, group_data_port, etc.
.SH OPTIONS
.TP 8
.B \-D
Enable daemon mode. All messages will be sent via syslog() instead of being
written to stderr.
.TP 8
.B \-V
Print version information for the program, and exit with status 3.
.TP 8
.BI \-a " aclfile"
Use the given aclfile, for the access control lists.
.TP 8
.B \-d
Increment debug level by one.
The debug level starts at zero (report errors only), and more detailed
messages are given as the level increases.
.TP 8
.BI \-g " group"
The numeric group ID (default=1).
.TP 8
.B \-h
A help message is printed, and afdpsend exits with status 2.
.TP 8
.BI \-p " port"
Use the given port for FIND_SECRETARY messages.
Port may be a number, or a service name as listed in /etc/services.
.TP 8
.B \-r
Use reserved ports (root only).
.TP 8
.BI \-s " secretary"
Hostname of secretary host to use.
If no '-s' option is given, the local network will be searched for
a secretary using broadcast packets.
.TP 8
.BI \-c " command"
The command that the subscribers should run after they receive each file.
.TP 8
.B \-C " cache_size"
Sets file cache size used by publisher (default = 100,000 bytes).
.TP 8
.BI \-o " confirm"
(not implemented yet)
Enables the confirm_receipt feature of the AFDP protocol,
which asks subscribers to send an acknowledgement to the
publisher after each message.
.TP 8
.BI \-o " warn"
(not implemented yet)
Enables the warn_resending feature of the AFDP protocol,
where the publisher warns subscribers that it is about to
resend some missed packets.
This is used to prevent subscribers from needing to
send resend requests when used together with the random_wait option.
.TP 8
.B \-M
Disables use of multicast transport mode.
.TP 8
.B \-N
Sets 'be nice to network' mode,
where minimum inter-packet interval is 100 ms.
.TP 8
.B \-R
Sets 'rabid' mode (opposite of '-N' option),
where minimum inter-packet interval is 2 ms.
.TP 8
.B \-S " stepsize"
Sets stepsize, in ms, used for rate-based flow control (default = 10 ms).
.TP 8
.B \-U
Sets 'unicast resends' mode so that resent packets are sent directly
to the host that requested them (appropriate if many hosts don't
request the same packets).
.TP 8
.B \-b " broadcast_size"
Sets size of broadcast data packets (default = 1436 bytes).
.TP 8
.B \-i " interval"
Sets starting inter-packet interval, in ms (default = 25 ms).
.TP 8
.B \-u " unicast_size"
Sets size of unicast and multicast data packets (default = 8968 bytes).
.TP 8
.B \-w " window_size"
Sets window size, used to control resend requests
(default = 100 message packets).
.SH "EXAMPLES"
.TP
afdpsend -c magic-cat report.ps picture.gif message.au
Sends 3 files to afdp group #1 on local network.
Subscribers will use magic-cat to 'view' the files as they are received.
.TP
afdpsend -d -s stealth.ecf -g 55 -c pwconv /etc/passwd
Sends /etc/passwd file to group 55, which has secretary on host stealth.ecf.
Each subscriber will run 'pwconv' after receiving the file.
.SH "SEE ALSO"
afdpjoin(1), magic-cat(1)
.SH DIAGNOSTICS
Exit status of 0 indicates normal status, 1 if secretary cannot
be found, 2 for syntax errors, 3 for unimplemented option,
5 for system call failures, 4 for other errors.
.SH "BUGS"
.PP
Should use multicast, with ttl>1 to search neighbouring networks for secretary.
.SH COPYRIGHT
Copyright (c) 1994, 1995  by Jeremy Cooperstock and Steve Kotsopoulos,
All Rights Reserved.
.SH AUTHORS
Jeremy Cooperstock <jer@dgp.toronto.edu> and
Steve Kotsopoulos <steve@ecf.toronto.edu>, University of Toronto.
